summaryrefslogtreecommitdiffstats
path: root/kmymoney2/converter
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:08:33 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:08:33 -0600
commit6078e14f28ec3b34cc2041cbd8628a1d8420512c (patch)
treec1fc7025048f77334cf5e4d9c76b7ba5ecc12ba7 /kmymoney2/converter
parent6c1d52c8248adb9189c944a28efde52330e99b66 (diff)
downloadkmymoney-6078e14f28ec3b34cc2041cbd8628a1d8420512c.tar.gz
kmymoney-6078e14f28ec3b34cc2041cbd8628a1d8420512c.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'kmymoney2/converter')
-rw-r--r--kmymoney2/converter/mymoneyqifprofile.cpp4
-rw-r--r--kmymoney2/converter/mymoneyqifreader.cpp10
-rw-r--r--kmymoney2/converter/mymoneystatementreader.cpp2
-rw-r--r--kmymoney2/converter/mymoneytemplate.cpp8
-rw-r--r--kmymoney2/converter/webpricequote.cpp30
-rw-r--r--kmymoney2/converter/webpricequote.h6
6 files changed, 30 insertions, 30 deletions
diff --git a/kmymoney2/converter/mymoneyqifprofile.cpp b/kmymoney2/converter/mymoneyqifprofile.cpp
index 079716d..d65a384 100644
--- a/kmymoney2/converter/mymoneyqifprofile.cpp
+++ b/kmymoney2/converter/mymoneyqifprofile.cpp
@@ -186,7 +186,7 @@ void MyMoneyQifProfile::clear(void)
void MyMoneyQifProfile::loadProfile(const TQString& name)
{
- KConfig* config = TDEGlobal::config();
+ TDEConfig* config = TDEGlobal::config();
config->setGroup(name);
clear();
@@ -232,7 +232,7 @@ void MyMoneyQifProfile::loadProfile(const TQString& name)
void MyMoneyQifProfile::saveProfile(void)
{
if(m_isDirty == true) {
- KConfig* config = TDEGlobal::config();
+ TDEConfig* config = TDEGlobal::config();
config->setGroup(m_profileName);
config->writeEntry("Description", m_profileDescription);
diff --git a/kmymoney2/converter/mymoneyqifreader.cpp b/kmymoney2/converter/mymoneyqifreader.cpp
index bcb9091..2e7266b 100644
--- a/kmymoney2/converter/mymoneyqifreader.cpp
+++ b/kmymoney2/converter/mymoneyqifreader.cpp
@@ -402,10 +402,10 @@ bool MyMoneyQifReader::startImport(void)
m_filename = TQString();
m_data.clear();
- if(!KIO::NetAccess::download(m_url, m_filename, NULL)) {
+ if(!TDEIO::NetAccess::download(m_url, m_filename, NULL)) {
KMessageBox::detailedError(0,
i18n("Error while loading file '%1'!").arg(m_url.prettyURL()),
- KIO::NetAccess::lastErrorString(),
+ TDEIO::NetAccess::lastErrorString(),
i18n("File access error"));
return false;
}
@@ -459,7 +459,7 @@ bool MyMoneyQifReader::finishImport(void)
m_file = 0;
// remove the Don't ask again entries
- KConfig* config = TDEGlobal::config();
+ TDEConfig* config = TDEGlobal::config();
config->setGroup(TQString::fromLatin1("Notification Messages"));
TQStringList::ConstIterator it;
@@ -479,7 +479,7 @@ bool MyMoneyQifReader::finishImport(void)
m_file = 0;
// remove the Don't ask again entries
- KConfig* config = TDEGlobal::config();
+ TDEConfig* config = TDEGlobal::config();
config->setGroup(TQString::fromLatin1("Notification Messages"));
TQStringList::ConstIterator it;
@@ -500,7 +500,7 @@ bool MyMoneyQifReader::finishImport(void)
// if a temporary file was constructed by NetAccess::download,
// then it will be removed with the next call. Otherwise, it
// stays untouched on the local filesystem
- KIO::NetAccess::removeTempFile(m_filename);
+ TDEIO::NetAccess::removeTempFile(m_filename);
#if 0
// Add the transaction entries
diff --git a/kmymoney2/converter/mymoneystatementreader.cpp b/kmymoney2/converter/mymoneystatementreader.cpp
index a242f41..8bef60e 100644
--- a/kmymoney2/converter/mymoneystatementreader.cpp
+++ b/kmymoney2/converter/mymoneystatementreader.cpp
@@ -401,7 +401,7 @@ bool MyMoneyStatementReader::import(const MyMoneyStatement& s, TQStringList& mes
messages += TQString();
// remove the Don't ask again entries
- KConfig* config = TDEGlobal::config();
+ TDEConfig* config = TDEGlobal::config();
config->setGroup(TQString::fromLatin1("Notification Messages"));
TQStringList::ConstIterator it;
diff --git a/kmymoney2/converter/mymoneytemplate.cpp b/kmymoney2/converter/mymoneytemplate.cpp
index 553e682..191474f 100644
--- a/kmymoney2/converter/mymoneytemplate.cpp
+++ b/kmymoney2/converter/mymoneytemplate.cpp
@@ -67,11 +67,11 @@ bool MyMoneyTemplate::loadTemplate(const KURL& url)
} else {
bool rc;
- rc = KIO::NetAccess::download(url, filename, tqApp->mainWidget());
+ rc = TDEIO::NetAccess::download(url, filename, tqApp->mainWidget());
if(!rc) {
KMessageBox::detailedError(tqApp->mainWidget(),
i18n("Error while loading file '%1'!").arg(url.url()),
- KIO::NetAccess::lastErrorString(),
+ TDEIO::NetAccess::lastErrorString(),
i18n("File access error"));
return false;
}
@@ -105,7 +105,7 @@ bool MyMoneyTemplate::loadTemplate(const KURL& url)
// if a temporary file was constructed by NetAccess::download,
// then it will be removed with the next call. Otherwise, it
// stays untouched on the local filesystem
- KIO::NetAccess::removeTempFile(filename);
+ TDEIO::NetAccess::removeTempFile(filename);
return rc;
}
@@ -403,7 +403,7 @@ bool MyMoneyTemplate::saveTemplate(const KURL& url)
} else {
KTempFile tmpfile;
saveToLocalFile(tmpfile.file());
- if(!KIO::NetAccess::upload(tmpfile.name(), url, NULL))
+ if(!TDEIO::NetAccess::upload(tmpfile.name(), url, NULL))
throw new MYMONEYEXCEPTION(i18n("Unable to upload to '%1'").arg(url.url()));
tmpfile.unlink();
}
diff --git a/kmymoney2/converter/webpricequote.cpp b/kmymoney2/converter/webpricequote.cpp
index ba9cdc4..b614dcc 100644
--- a/kmymoney2/converter/webpricequote.cpp
+++ b/kmymoney2/converter/webpricequote.cpp
@@ -122,7 +122,7 @@ bool WebPriceQuote::launchNative( const TQString& _symbol, const TQString& _id,
url = KURL::fromPathOrURL(m_source.m_url.arg(m_symbol));
// If we're running a non-interactive session (with no UI), we can't
// use KIO::NetAccess, so we have to get our web data the old-fashioned
// way... with 'wget'.
//
// Note that a 'non-interactive' session right now means only the test
@@ -180,7 +180,7 @@ bool WebPriceQuote::launchNative( const TQString& _symbol, const TQString& _id,
}
else
{
- emit error(KIO::NetAccess::lastErrorString());
+ emit error(TDEIO::NetAccess::lastErrorString());
slotParseQuote(TQString());
}
}
@@ -199,7 +199,7 @@ bool WebPriceQuote::download(const KURL& u, TQString & target, TQWidget* window)
{
m_tmpFile = TQString();
// the following code taken and adapted from KIO::NetAccess::download()
if (target.isEmpty())
{
KTempFile tmpFile;
@@ -211,22 +211,22 @@ bool WebPriceQuote::download(const KURL& u, TQString & target, TQWidget* window)
dest.setPath( target );
// the following code taken and adapted from KIO::NetAccess::filecopyInternal()
bJobOK = true; // success unless further error occurs
- KIO::Scheduler::checkSlaveOnHold(true);
- KIO::Job * job = KIO::file_copy( u, dest, -1, true, false, false );
+ TDEIO::Scheduler::checkSlaveOnHold(true);
+ TDEIO::Job * job = TDEIO::file_copy( u, dest, -1, true, false, false );
job->setWindow (window);
job->addMetaData("cache", "reload"); // bypass cache
- connect( job, TQT_SIGNAL( result (KIO::Job *) ),
- this, TQT_SLOT( slotResult (KIO::Job *) ) );
+ connect( job, TQT_SIGNAL( result (TDEIO::Job *) ),
+ this, TQT_SLOT( slotResult (TDEIO::Job *) ) );
enter_loop();
return bJobOK;
}
// The following parts are copied and adjusted from KIO::NetAccess
// If a troll sees this, he kills me
void tqt_enter_modal( TQWidget *widget );
@@ -241,7 +241,7 @@ void WebPriceQuote::enter_loop(void)
tqt_leave_modal(&dummy);
}
-void WebPriceQuote::slotResult( KIO::Job * job )
+void WebPriceQuote::slotResult( TDEIO::Job * job )
{
lastErrorCode = job->error();
bJobOK = !job->error();
@@ -254,7 +254,7 @@ void WebPriceQuote::slotResult( KIO::Job * job )
tqApp->exit_loop();
}
// The above parts are copied and adjusted from KIO::NetAccess
bool WebPriceQuote::launchFinanceQuote ( const TQString& _symbol, const TQString& _id,
const TQString& _sourcename ) {
@@ -598,7 +598,7 @@ TQStringList WebPriceQuote::quoteSources (const _quoteSystemE _system) {
TQStringList WebPriceQuote::quoteSourcesNative()
{
- KConfig *kconfig = TDEGlobal::config();
+ TDEConfig *kconfig = TDEGlobal::config();
TQStringList groups = kconfig->groupList();
TQStringList::Iterator it;
@@ -683,7 +683,7 @@ WebPriceQuoteSource::WebPriceQuoteSource(const TQString& name, const TQString& u
WebPriceQuoteSource::WebPriceQuoteSource(const TQString& name)
{
m_name = name;
- KConfig *kconfig = TDEGlobal::config();
+ TDEConfig *kconfig = TDEGlobal::config();
kconfig->setGroup(TQString("Online-Quote-Source-%1").arg(m_name));
m_sym = kconfig->readEntry("SymbolRegex");
m_date = kconfig->readEntry("DateRegex");
@@ -695,7 +695,7 @@ WebPriceQuoteSource::WebPriceQuoteSource(const TQString& name)
void WebPriceQuoteSource::write(void) const
{
- KConfig *kconfig = TDEGlobal::config();
+ TDEConfig *kconfig = TDEGlobal::config();
kconfig->setGroup(TQString("Online-Quote-Source-%1").arg(m_name));
kconfig->writeEntry("URL", m_url);
kconfig->writeEntry("PriceRegex", m_price);
@@ -717,7 +717,7 @@ void WebPriceQuoteSource::rename(const TQString& name)
void WebPriceQuoteSource::remove(void) const
{
- KConfig *kconfig = TDEGlobal::config();
+ TDEConfig *kconfig = TDEGlobal::config();
kconfig->deleteGroup(TQString("Online-Quote-Source-%1").arg(m_name));
}
@@ -122,7 +122,7 @@ bool WebPriceQuote::launchNative( const TQString& _symbol, const TQString& _id,
url = KURL::fromPathOrURL(m_source.m_url.arg(m_symbol));
// If we're running a non-interactive session (with no UI), we can't
- // use KIO::NetAccess, so we have to get our web data the old-fashioned
+ // use TDEIO::NetAccess, so we have to get our web data the old-fashioned
// way... with 'wget'.
//
@@ -199,7 +199,7 @@ bool WebPriceQuote::download(const KURL& u, TQString & target, TQWidget* window)
{
m_tmpFile = TQString();
- // the following code taken and adapted from KIO::NetAccess::download()
+ // the following code taken and adapted from TDEIO::NetAccess::download()
if (target.isEmpty())
{
@@ -211,22 +211,22 @@ bool WebPriceQuote::download(const KURL& u, TQString & target, TQWidget* window)
dest.setPath( target );
- // the following code taken and adapted from KIO::NetAccess::filecopyInternal()
+ // the following code taken and adapted from TDEIO::NetAccess::filecopyInternal()
bJobOK = true; // success unless further error occurs
@@ -211,22 +211,22 @@ bool WebPriceQuote::download(const KURL& u, TQString & target, TQWidget* window)
return bJobOK;
}
-// The following parts are copied and adjusted from KIO::NetAccess
+// The following parts are copied and adjusted from TDEIO::NetAccess
// If a troll sees this, he kills me
void tqt_enter_modal( TQWidget *widget );
@@ -254,7 +254,7 @@ void WebPriceQuote::slotResult( KIO::Job * job )
tqApp->exit_loop();
}
-// The above parts are copied and adjusted from KIO::NetAccess
+// The above parts are copied and adjusted from TDEIO::NetAccess
bool WebPriceQuote::launchFinanceQuote ( const TQString& _symbol, const TQString& _id,
const TQString& _sourcename ) {
diff --git a/kmymoney2/converter/webpricequote.h b/kmymoney2/converter/webpricequote.h
index a9ec149..411d100 100644
--- a/kmymoney2/converter/webpricequote.h
+++ b/kmymoney2/converter/webpricequote.h
@@ -30,7 +30,7 @@
// KDE Headers
#include <kprocess.h>
-namespace KIO {
+namespace TDEIO {
class Job;
};
@@ -182,7 +182,7 @@ private:
void removeTempFile(const TQString& tmpFile);
private slots:
- void slotResult( KIO::Job * job );
+ void slotResult( TDEIO::Job * job );
private:
@@ -204,7 +204,7 @@ private:
/**
* Whether the download succeeded or not. Taken from KIO::NetAccess
*/
bool bJobOK;
static TQString* lastErrorMsg;
@@ -204,7 +204,7 @@ private:
/**
- * Whether the download succeeded or not. Taken from KIO::NetAccess
+ * Whether the download succeeded or not. Taken from TDEIO::NetAccess
*/
bool bJobOK;